@@ -20,9 +20,8 @@
 #ifndef __GCONF_EDITOR_APPLICATION_H__
 #define __GCONF_EDITOR_APPLICATION_H__
 
-#include <gtk/gtkwidget.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
 
-GtkWidget *gconf_editor_application_create_editor_window (void);
+GtkWidget *gconf_editor_application_create_editor_window (int type);
 
 #endif /* __GCONF_EDITOR_APPLICATION_H__ */
