@@ -116,20 +116,20 @@ gconf_key_editor_create_combo_box (GConfKeyEditor *editor)
 {
 	GtkWidget *combo_box;
 
-	combo_box = gtk_combo_box_new_text ();
+	combo_box = gtk_combo_box_text_new ();
 
 	/* These have to be ordered so the EDIT_ enum matches the
 	 * menu indices
 	 */
 
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Integer"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Boolean"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("String"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo_box), _("Integer"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo_box), _("Boolean"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo_box), _("String"));
 	/* Translators: this refers to "Floating point":
 	 * see http://en.wikipedia.org/wiki/Floating_point
 	 */
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Float"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("List"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo_box), _("Float"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo_box), _("List"));
 
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combo_box), 0);
 
@@ -146,15 +146,15 @@ gconf_key_editor_create_list_type_menu (GConfKeyEditor *editor)
 {
 	GtkWidget *combo_box;
 
-	combo_box = gtk_combo_box_new_text ();
+	combo_box = gtk_combo_box_text_new ();
 
 	/* These have to be ordered so the EDIT_ enum matches the
 	 * combobox indices
 	 */
 
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Integer"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Boolean"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("String"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo_box), _("Integer"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo_box), _("Boolean"));
+	gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo_box), _("String"));
 
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combo_box), 0);
 	
@@ -227,7 +227,6 @@ list_add_clicked (GtkButton *button,
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_box_set_spacing (GTK_BOX (content_area), 2);
 	
@@ -332,7 +331,6 @@ list_edit_element (GConfKeyEditor *editor)
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_box_set_spacing (GTK_BOX (content_area), 2);
 	
@@ -551,7 +549,6 @@ gconf_key_editor_init (GConfKeyEditor *editor)
 	gtk_dialog_set_default_response (GTK_DIALOG (editor), GTK_RESPONSE_OK);
 
 	gtk_container_set_border_width (GTK_CONTAINER (editor), 5);
-	gtk_dialog_set_has_separator (GTK_DIALOG (editor), FALSE);
 	gtk_window_set_resizable (GTK_WINDOW (editor), FALSE);
 	gtk_box_set_spacing (GTK_BOX (content_area), 2);
 
